<!DOCTYPE html>
<html lang="en">

<head>
    <!-- Meta and Title -->
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Chat with <%= process.env.OWNER_NAME %>'s AI assistant">

    <title>Chat with AI - <%= process.env.OWNER_NAME %></title>
    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css">
    <!-- Font Awesome CSS for Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <!-- Custom CSS -->
    <link rel="stylesheet" href="<%= process.env.HOST_URL %>/css/styles.css">
    <link rel="apple-touch-icon" sizes="180x180" href="<%= process.env.HOST_URL %>/apple-touch-icon.png">
    <link rel="icon" type="image/png" sizes="32x32" href="<%= process.env.HOST_URL %>/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="16x16" href="<%= process.env.HOST_URL %>/favicon-16x16.png">
    <link rel="manifest" href="<%= process.env.HOST_URL %>/site.webmanifest">
    <meta name="msapplication-TileColor" content="#da532c">
    <meta name="theme-color" content="#ffffff">
    <!-- reCAPTCHA API -->
    <script src="https://www.google.com/recaptcha/api.js" async defer></script>
</head>

<body class="bg-dark text-white">

    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <div class="container-fluid">
            <a class="navbar-brand" href="<%= process.env.HOST_URL %>"><%= process.env.SITE_NAME %></a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <% menuItems.forEach(item => { %>
                        <li class="nav-item">
                            <a class="nav-link" href="<%= item.url %>" <%= item.openNewPage ? 'target="_blank"' : '' %>><%= item.title %></a>
                        </li>
                    <% }) %>
                </ul>
            </div>
        </div>
    </nav>

    <!-- Chat Section -->
    <header class="d-flex align-items-center justify-content-center text-center py-5">
        <div class="container">
            <h2 class="mb-4 text-white">Chat with <%= process.env.OWNER_NAME %>'s AI</h2>
            <p class="lead text-white">Ask any question, and the AI will respond to you!</p>

            <!-- Chat Box -->
            <div id="chatBox" class="bg-light p-4 rounded text-dark mb-4">
                <div id="messages" class="mb-3" style="max-height: 300px; overflow-y: scroll;"></div>

                <textarea id="messageInput" class="form-control mb-2 bg-dark text-white" rows="3" placeholder="Type your message here..." onkeydown="handleKeyDown(event)"></textarea>
                <button class="btn btn-primary w-100" onclick="sendMessage()">Send Message</button>

                <!-- Loading Indicator -->
                <div id="loading" class="text-center mt-3" style="display: none;">
                    <div class="spinner-border text-primary" role="status">
                        <span class="visually-hidden">Loading...</span>
                    </div>
                </div>
            </div>

            <!-- Alert Messages -->
            <div id="success-alert" class="alert alert-success mt-3" style="display: none;"></div>
            <div id="error-alert" class="alert alert-danger mt-3" style="display: none;"></div>

        </div>
    </header>

    <!-- Footer -->
    <footer class="text-white text-center py-4">
        <div class="container">
            <p class="mb-0">&copy; 2024 <%= process.env.OWNER_NAME %>. All rights reserved.</p>
        </div>
    </footer>

    <!-- Bootstrap JS Bundle -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Additional Libraries -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/marked/3.0.7/marked.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.6.0/highlight.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/he@1.2.0/he.min.js"></script>

    <!-- Inline JavaScript -->
    <script>
        // Handles key down event to send message on Enter
        function handleKeyDown(event) {
            if (event.key === 'Enter' && !event.shiftKey) {
                event.preventDefault();
                sendMessage();
            }
        }

        // Sends a message to the chat API
        async function sendMessage() {
            const messageInput = document.getElementById('messageInput');
            let message = messageInput.value.trim();

            if (message === '') return;

            // Encode the message to avoid XSS attacks
            message = he.encode(message);

            // Display the user's message in the chat
            displayMessage(message, 'user');
            messageInput.value = ''; // Clear the input
            toggleLoading(true); // Show loading indicator

            try {
                const response = await fetch('https://infer.x64.world/chat', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({ message: message })
                });

                if (response.ok) {
                    const data = await response.json();
                    displayMessage(data.content, 'assistant');
                } else {
                    handleErrorResponse(response.status);
                }
            } catch (error) {
                displayMessage('Error: ' + error.message, 'assistant');
            } finally {
                toggleLoading(false); // Hide loading indicator
            }
        }

        // Toggles the loading indicator
        function toggleLoading(show) {
            const loadingElement = document.getElementById('loading');
            loadingElement.style.display = show ? 'block' : 'none';
        }

        // Displays a message in the chat window
        function displayMessage(content, sender) {
            const messages = document.getElementById('messages');
            const messageElement = document.createElement('div');
            messageElement.classList.add('message', sender);

            // Decode HTML entities and render Markdown
            const decodedContent = he.decode(content);
            const htmlContent = marked(decodedContent);
            messageElement.innerHTML = htmlContent;

            messages.appendChild(messageElement);
            messages.scrollTop = messages.scrollHeight; // Scroll to the bottom of the chat

            // Highlight code blocks if any
            document.querySelectorAll('pre code').forEach((block) => {
                hljs.highlightBlock(block);
                if (sender === 'assistant') {
                    addCopyButton(block); // Add copy button to code blocks
                }
            });
        }

        // Adds a copy button to a code block
        function addCopyButton(block) {
            const button = document.createElement('button');
            button.classList.add('copy-button');
            button.textContent = 'Copy';
            button.addEventListener('click', () => copyToClipboard(block));
            block.parentNode.appendChild(button);
        }

        // Copies code block content to the clipboard
        function copyToClipboard(block) {
            const text = block.innerText;
            navigator.clipboard.writeText(text).then(() => {
                displayAlert('success', 'The code block was copied to the clipboard!');
            }).catch((err) => {
                displayAlert('error', 'Failed to copy code: ' + err);
            });
        }

        // Displays an alert message
        function displayAlert(type, message) {
            const alertElement = document.getElementById(`${type}-alert`);
            alertElement.textContent = message;
            alertElement.style.display = 'block';
            setTimeout(() => {
                alertElement.style.display = 'none';
            }, 3000);
        }

        // Handles error responses based on status code
        function handleErrorResponse(status) {
            if (status === 429) {
                displayAlert('error', 'Sorry, I am currently too busy at the moment!');
            } else {
                displayMessage('Error: ' + status, 'assistant');
            }
        }
    </script>

</body>

</html>
